===============
Introduction
===============

.. code-block:: shell

    pip install waloviz
    apt-get install ffmpeg

.. notebook:: holoviews ../examples/introduction.ipynb
    :offset: 1

**An interactive audio player with a spectrogram built-in, as a Jupyter widget or as HTML.**

| Welcome!
| WaloViz is an open source audio player with a spectrogram built-in, it was built by audio experts - for audio experts.
| To start using WaloViz right now - read our `Getting Started <./getting-started.html>`_ guide.
| You can also try ``waloviz`` right now with our `Google Colab Demo <https://colab.research.google.com/drive/1euQCxaNlTg0pGvXz6d7RSoDhM3B1k7dy?usp=sharing>`_ :)
| WaloViz is proudly using the HoloViz stack for most of its features (as indicated by our name). To learn more - go to `the HoloViz website <https://holoviz.org/>`_, it's great :)
|
| To learn what WaloViz is all about, read `About Us :  <./about.html>`_ |:information_source:|

.. toctree::
    :titlesonly:
    :hidden:
    :maxdepth: 2

    Introduction <self>
    Getting Started <getting-started>
    User Guide <user-guide/index>
    API <reference-manual/index>
    Releases <releases>
    FAQ <FAQ>
    About <about>
